#
# spec file for package xastir
#
# Copyright (c) 2021-2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           xastir
Version:        2.1.8
Release:        lp155.2.2
License:        GPL-2.0
Summary:        Automatic Packet Reporting System client
URL:            http://www.xastir.org
Group:          Productivity/Hamradio/Other
Source0:        xastir-%{version}.tar.bz2
Source1:        xastir-sounds.tar.bz2
Source2:        xastir.png
BuildRequires:  automake autoconf
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1500
BuildRequires:  festival-devel
%endif
BuildRequires:  gpsman
BuildRequires:  libax25-devel
BuildRequires:  libbz2-devel
BuildRequires:  libcurl-devel
BuildRequires:  libdb-4_8-devel
%if 0%{?suse_version} > 1500
BuildRequires:  hdf5-devel
%else
BuildRequires:  hdf-devel
%endif
BuildRequires:  liblcms2-devel
BuildRequires:  libgeotiff-devel
BuildRequires:  libproj-devel
BuildRequires:  libshp-devel
BuildRequires:  libtool
BuildRequires:  libXpm-devel
BuildRequires:  openmotif-devel
BuildRequires:  pcre-devel
BuildRequires:  postgresql-devel
BuildRequires:  shapelib
BuildRequires:  update-desktop-files
BuildRequires:  xz-devel
#BuildRequires:  GraphicsMagick-devel

%description
Xastir is a graphical client application for the Automatic Packet Reporting
System (APRS™) (also known as "Automatic Position Reporting System"). It is
an amateur radio based digital communication system for real-time exchange
of digital information to users on the network.

%prep
%setup -q -a1

%build
./bootstrap.sh
%configure CPPFLAGS="-I/usr/include/libgeotiff"
%make_build

%install
%make_install
# Docs go into package docs area instead of here:
rm -rf %{buildroot}%{_datadir}/doc/xastir
chmod +x %{buildroot}%{_datadir}/xastir/scripts/*
cp sounds/* %{buildroot}%{_datadir}/xastir/sounds/.
%suse_update_desktop_file -c xastir Xastir 'APRS Program' xastir xastir 'Network;HamRadio'
%fdupes -s %{buildroot}%{_datadir}

%files
%doc AUTHORS ChangeLog DEBUG_LEVELS FAQ LICENSE
%doc README README.* UPGRADE
%license  COPYING COPYING.LIB.LESSTIF
%{_bindir}/*
%{_datadir}/xastir
%{_mandir}/man1/xastir.1.gz
%{_mandir}/man1/callpass.1.gz
%{_mandir}/man1/testdbfawk.1.gz
%{_mandir}/man1/xastir_udp_client.1.gz
%{_datadir}/pixmaps/xastir.png
%{_datadir}/applications/xastir.desktop

%changelog
* Fri Jul  7 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fixed build for Tumbleweed and Factory
- Cleanup of specfile
- Enabled picture save via Xcb
- Disabled GraphicMagick (version 7 not supported yet)
- Disabled festival support on Tumbleweed and Factory
* Tue Dec 21 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.1.8
  * This is primarily a maintenance release to assure that build
    problems on some distros are addressed in released code, but
    there are a few bug fixes in it as well.
  - The Xastir project no longer provides tar files that have
    been "bootstrapped"
  - If Xastir crashes, instances of the network server no longer
    stick around to interfere with starting up a new copy of
    Xastir. (issue #130)
  - The get-NWSdata script now correctly respects the install
    prefix in all its steps (pull request #172)
  - Xastir's probe for libproj no longer looks for the deprecated
    function pj_init, making it compatible with newer versions
    of the proj library. (issue #173)
  - Some unused, buggy diagnostic code has been removeds. (issue
    [#174])
  - Some very ancient autoconf code was updated to work with more
    recent versions of autoconf. This removes several deprecation
    warnings, but more importantly removes fatal errors in the
    most recent version of automake (pull request #181)
  - The "install-xastir" script has been removed.
- Patch configure.diff removed. After update, the  configure script
  can detect GraphicMagick by itself
- Fixed build for Tumbleweed
* Wed Apr 29 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.1.6
  * Miscellaneous improvements to ADB-B and AIS processing scripts
  * Many warnings from gcc 9 have been cleaned up. There are still
    some from gcc 10.
  * The old Xastir_tigerpoly.pl script has been removed.
  * Some http: URLs have been replaced with the correct https:
    URL in map fetching scripts.
  * The get-gnis script no longer looks for date-stamped files.
  * NWS shapefile scripts have been updated to fetch the latest
    versions, and apropriate DBFAWK files updated.
  * A bug in weather alert parsing was fixed.
  * The bootstrap script now exits with an error if any of the
    tools it requires are not found.
  * Numerous compilation problems with gcc 10 have been fixed.
  * Configuration dialog boxes now auto-size to fit the screen,
    and provide scroll bars if the contents of the dialog box are
    too big to fit.
  * Davis/LaCrosse weather station code no longer clobbers good,
    computed wind gust values when it receives "g..." from the
    database daemon. Xastir computes wind gust itself from the wind
    speed history, and will now only overwrite that computed value
    when the weather station computes a valid gust value itself.
* Thu Aug 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.1.4
  * Code reformatting to match new project style
  * Numerous updates to decrease number of warnings from gcc8
  * Fix compiler warnings from OS X clang about use of hard-coded
    degree symbols in strings.
  * Removed the "--without-rtree" option: rtree is now always built
    into Xastir if shapefile support is enabled.
  * Removed vestigial references to gettext/libintl internationalization,
    which hasn't actually been used since at least 2002
  * Fix compilation error with GraphicsMagick 1.3.32 and later.
* Tue Jun 11 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2.1.2
  * National Weather Service shapefile script updated, dbfawk files
    added.
  * Compilation errors in OS X earlier than 10.6 fixed.
  * Tiger WMS server maps added.
  * A new set of National Map .geo files replaces those that
    referenced WMS products that have gone off-line since the last
    release.
  * GDAL and OGR support removed.
  * Xastir builds are now reproducible (builds no longer contain
    the build date and time).
  * Deprecated GraphicsMagick and ImageMagick function calls
    replaced with new API.
  * Download of tiled maps is now handled by a download manager
    running in a separate thread, dramatically improving map update
    speed.
  * Obsolete interface to old Tiger/Line map server removed (the
    server went down years ago).
  * OpenTrac decoding support removed.
  * Support for the old PocketAPRS (PalmOS based APRS) map format
    has     been removed. Users of these old map types should
    transition to a more modern format.
  * Xastir sources no longer contains a copy of an old version of
    shapelib source. Shapelib support must now always be provided
    by an external library.
  * The embryonic "Xastir-qt" project has been moved to a separate
    repository.
  * "Xastir -V" will now cause Xastir to report its version number
    (with git sha-1 hash appended if built from a git clone) and
    exit.
  * Support for many additional satellite navigation (GNSS)
    receivers has been added to the existing GPS support. Prior to
    this release, only NMEA sentences starting with $GP were
    recognized.
  * Many compilation warnings from recent GCC and Clang compilers
    have been eliminated, resulting in a cleaner build.
  * Our Makefiles now default to "silent rules" to reduce
    uninteresting output during compliation. The old, noisier
    behavior may be invoked by adding "V=1" to the "make" line at
    build time.
  * The configure summary now shows the status of its probe for Xpm
    libraries under "Xpm / Snapshots".
* Sun May 20 2018 wk@ire.pw.edu.pl
- Update to version 2.1.0
* Wed Apr 13 2016 arnd@gronenberg.com
- hdf-devel build requisite added
* Thu Feb 12 2015 dl8fcl@darc.de
- force configure to use GraphicsMagick
* Fri Sep 19 2014 dl8fcl@darc.de
- linked to GraphicsMagic 1.3.20 to enable Raster and online maps.
* Thu Sep 18 2014 dl8fcl@darc.de
- Update to version 2.0.6
  libgeotiff included
* Wed Feb 27 2013 dl8fcl@darc.de
- Dependencies for 12.3 fixed
* Thu Dec 20 2012 dl8fcl@darc.de
- Update to version 2.0.4
* Thu Jul 15 2010 Tim Fischer <dg7gt@gmx.de
- Update to Version 1.9.8
- Dependency updates for openSUSE 11.3
* Sat Nov 21 2009 Tim Fischer <dg7gt@gmx.de>
- Update to Version 1.9.6
- Some dependency updates for openSUSE 11.2
* Sun Feb  8 2009 Tim Fischer <dg7gt@online.de
- temporrarily disabled RPM Lint checks to make it build under 11.1
* Sun Jun  1 2008 Tim Fischer <dg7gt@online.de>
- updated to xastir 1.9.2
- links from Application:Geo
* Mon May 28 2007 Tim Fischer <dg7gt@online.de>
- updated to xastir 1.9.0
- corrected path to man page
* Wed Feb 21 2007 Tim Fischer <dg7gt@online.de>
- some adjustments in builrequires for openSUSE Buildservice
* Sat Dec 16 2006 Tim Fischer <dg7gt@online.de>
- Updated to version 1.8.4
- added xastir-sounds
- updated BuildRequires
* Mon Jun 19 2006 Tim Fischer <dg7gt@online.de>
- Partially rewrite spec file for SUSE 10.1
* Thu Jul  3 2003 Alan Crosswell <n2ygk@weca.org> 
- 1.2.1 my patches now integrated into the main trunk.
* Sat Jun 21 2003 Alan Crosswell <n2ygk@weca.org> 
- added xastir-maps.patch
* Mon Jun 16 2003 Alan Crosswell <n2ygk@weca.org> 
- 1.2.0
* Fri Jun  6 2003 Alan Crosswell <n2ygk@weca.org> 
- June 5 snapshot
* Thu May 15 2003 Alan Crosswell <n2ygk@weca.org> 
- start with chuck's spec file for 1.1.4
